@@ -2,6 +2,8 @@
 Encapsulations of the tools supported by blight.
 """
 
+import itertools
+import json
 import logging
 import os
 import re
@@ -87,6 +89,8 @@ class Tool:
         self._cwd = Path(os.getcwd()).resolve()
         self._actions = util.load_actions()
         self._skip_run = False
+        self._action_results: Dict[str, Dict[str, Any]] = {}
+        self._journal_path = os.getenv("BLIGHT_JOURNAL_PATH")
 
     def _fixup_env(self) -> Dict[str, str]:
         """
@@ -108,6 +112,14 @@ class Tool:
         for action in self._actions:
             action._after_run(self, run_skipped=self._skip_run)
 
+            if self.is_journaling():
+                self._action_results[action.__class__.__name__] = action.result
+
+    def _commit_journal(self) -> None:
+        if self.is_journaling():
+            with util.flock_append(self._journal_path) as io:  # type: ignore
+                json.dump(self._action_results, io)
+
     def run(self) -> None:
         """
         Runs the wrapped tool with the original arguments.
@@ -123,6 +135,15 @@ class Tool:
 
         self._after_run()
 
+        self._commit_journal()
+
+    def is_journaling(self) -> bool:
+        """
+        Returns:
+            `True` if this `Tool` is in "journaling" mode.
+        """
+        return self._journal_path is not None
+
     def asdict(self) -> Dict[str, Any]:
         """
         Returns:
@@ -627,10 +648,58 @@ class CodeModelMixin:
         return code_model_map.get(code_model, CodeModel.Unknown)
 
 
+class LinkSearchMixin:
+    """
+    A mixin for tools that support the `-Lpath` and `-llib` syntaxes for specifying
+    library paths and libraries, respectively.
+    """
+
+    @property
+    def explicit_library_search_paths(self: CanonicalizedArgsProtocol) -> List[Path]:
+        """
+        Returns a list of library search paths that are explicitly specified in
+        the tool's invocation. Semantically, these paths are (normally) given
+        priority over all other search paths.
+
+        NOTE: This is **not** the same as the complete list of library search paths,
+        which is tool-specific and host-dependent.
+        """
+
+        shorts = util.collect_option_values(self.canonicalized_args, "-L")
+        longs = util.collect_option_values(
+            self.canonicalized_args, "--library-path", style=util.OptionValueStyle.EqualOrSpace
+        )
+
+        sorted_values = sorted(itertools.chain(shorts, longs), key=lambda v: v[0])
+
+        return [(self.cwd / value[1]).resolve() for value in sorted_values]
+
+    @property
+    def library_names(self: CanonicalizedArgsProtocol) -> List[str]:
+        """
+        Returns a list of library names (without suffixes) for libraries that
+        are explicitly specified in the tool's invocation.
+
+        NOTE: This list does not include any libraries that are
+        listed as "inputs" to the tool rather than as linkage specifications.
+        """
+
+        shorts = util.collect_option_values(self.canonicalized_args, "-l")
+        longs = util.collect_option_values(
+            self.canonicalized_args, "--library", style=util.OptionValueStyle.EqualOrSpace
+        )
+
+        sorted_values = sorted(itertools.chain(shorts, longs), key=lambda v: v[0])
+
+        return [f"lib{value[1]}" for value in sorted_values]
+
+
 # NOTE(ww): The funny mixin order here (`ResponseFileMixin` before `Tool`) and elsewhere
 # is because Python defines its class hierarchy from right to left. `ResponseFileMixin`
 # therefore needs to come first in order to properly override `canonicalized_args`.
-class CompilerTool(ResponseFileMixin, Tool, StdMixin, OptMixin, DefinesMixin, CodeModelMixin):
+class CompilerTool(
+    LinkSearchMixin, ResponseFileMixin, Tool, StdMixin, OptMixin, DefinesMixin, CodeModelMixin
+):
     """
     Represents a generic (C or C++) compiler frontend.
 
@@ -748,7 +817,7 @@ class CPP(Tool, StdMixin, DefinesMixin):
         return {**super().asdict(), "lang": self.lang.name, "std": self.std.name}
 
 
-class LD(ResponseFileMixin, Tool):
+class LD(LinkSearchMixin, ResponseFileMixin, Tool):
     """
     Represents the linker.
     """
