@@ -4,18 +4,66 @@ Helper utilities for blight.
 
 import argparse
 import contextlib
+import enum
 import fcntl
 import os
 import shlex
 import sys
 from pathlib import Path
-from typing import Any, List, NoReturn, Optional, Sequence
+from typing import Any, List, NoReturn, Optional, Sequence, Tuple
 
 from blight.exceptions import BlightError
 
 SWIZZLE_SENTINEL = "@blight-swizzle@"
 
 
+@enum.unique
+class OptionValueStyle(enum.Enum):
+    """
+    A collection of common option formatting styles in build tools.
+
+    This enumeration is not exhaustive.
+    """
+
+    Space = enum.auto()
+    """
+    Options that look like `-O foo`.
+    """
+
+    Mash = enum.auto()
+    """
+    Options that look like `-Ofoo`.
+    """
+
+    MashOrSpace = enum.auto()
+    """
+    Options that look like `-Ofoo` or `-O foo`.
+    """
+
+    Equal = enum.auto()
+    """
+    Options that look like `-O=foo`.
+    """
+
+    EqualOrSpace = enum.auto()
+    """
+    Options that look like `-O=foo` or `-O foo`.
+    """
+
+    def permits_equal(self) -> bool:
+        return self in [OptionValueStyle.Equal, OptionValueStyle.EqualOrSpace]
+
+    def permits_mash(self) -> bool:
+        return self in [OptionValueStyle.Mash, OptionValueStyle.MashOrSpace]
+
+    def permits_space(self) -> bool:
+        return self in [
+            OptionValueStyle.Space,
+            OptionValueStyle.MashOrSpace,
+            OptionValueStyle.EqualOrSpace,
+        ]
+
+
 def die(message: str) -> NoReturn:
     """
     Aborts the program with a final message.
@@ -34,6 +82,52 @@ def assert_never(x: NoReturn) -> NoReturn:
     assert False, f"unhandled type: {type(x).__name__}"  # pragma: no cover
 
 
+def collect_option_values(
+    args: Sequence[str],
+    option: str,
+    *,
+    style: OptionValueStyle = OptionValueStyle.MashOrSpace,
+) -> List[Tuple[int, str]]:
+    """
+    Given a list of arguments, collect the ones that look like options with values.
+
+    Supports multiple option "styles" via `OptionValueStyle`.
+
+    Args:
+        args (sequence): The arguments to search
+        option (str): The option prefix to search for
+        style: (OptionValueStyle): The option style to search for
+
+    Returns:
+        A list of tuples of (index, value) for matching options. The index in each
+        tuple is the argument index for the option itself.
+    """
+
+    # TODO(ww): There are a lot of error cases here. They should be thought out more.
+
+    values: List[Tuple[int, str]] = []
+    for (idx, arg) in enumerate(args):
+        if not arg.startswith(option):
+            continue
+
+        is_exact = arg == option
+        if is_exact and style.permits_space():
+            # -o foo is the only style that make sense here.
+            values.append((idx, args[idx + 1]))
+        elif not is_exact:
+            # We have -oSOMETHING, where SOMETHING might be:
+            # * A "mash", like `-Dfoo`
+            # * An equals, like `-D=foo`
+            if style.permits_mash():
+                # NOTE(ww): Assignment to work around black's confusing formatting.
+                suff = len(option)
+                values.append((idx, arg[suff:]))
+            elif style.permits_equal():
+                values.append((idx, arg.split("=", 1)[1]))
+
+    return values
+
+
 def rindex(items: Sequence[Any], needle: Any) -> Optional[int]:
     """
     Args:
@@ -105,7 +199,7 @@ def insert_items_at_idx(parent_items: Sequence[Any], idx: int, items: Sequence[A
 
 
 @contextlib.contextmanager
-def flock_append(filename):
+def flock_append(filename: os.PathLike):
     """
     Open the given file for appending, acquiring an exclusive lock on it in
     the process.
