@@ -2,6 +2,7 @@ import json
 import os
 import shlex
 import shutil
+from pathlib import Path
 
 import pytest
 
@@ -55,6 +56,19 @@ def test_tool_run(monkeypatch, tmp_path):
     assert isinstance(bench_record["elapsed"], int)
 
 
+def test_tool_run_journaling(monkeypatch, tmp_path):
+    journal_output = tmp_path / "journal.jsonl"
+    monkeypatch.setenv("BLIGHT_ACTIONS", "Record:Benchmark:FindOutputs")
+    monkeypatch.setenv("BLIGHT_JOURNAL_PATH", str(journal_output))
+
+    cc = tool.CC(["-v"])
+    cc.run()
+
+    journal = json.loads(journal_output.read_text())
+    assert set(journal.keys()) == {"Record", "Benchmark", "FindOutputs"}
+    assert all(isinstance(v, dict) for v in journal.values())
+
+
 def test_tool_args_property():
     cpp = tool.CPP(["a", "b", "c"])
 
@@ -152,6 +166,36 @@ def test_tool_response_file_recursion_limit(tmp_path):
     assert cc.canonicalized_args == ["-foo"] * tool.RESPONSE_FILE_RECURSION_LIMIT
 
 
+def test_tool_explicit_library_search_paths():
+    cc = tool.CC(
+        [
+            "-L.",
+            "--library-path",
+            "./bar",
+            "-L..",
+            "-L../foo",
+            "-L",
+            "foo",
+            "-L/lib",
+            "--library-path=../../baz",
+        ]
+    )
+    assert cc.explicit_library_search_paths == [
+        cc.cwd,
+        cc.cwd / "bar",
+        cc.cwd.parent,
+        cc.cwd.parent / "foo",
+        cc.cwd / "foo",
+        Path("/lib").resolve(),
+        cc.cwd.parent.parent / "baz",
+    ]
+
+
+def test_tool_library_names():
+    cc = tool.CC(["-lfoo", "-l", "bar", "-liberty"])
+    assert cc.library_names == ["libfoo", "libbar", "libiberty"]
+
+
 @pytest.mark.parametrize(
     ("flags", "defines", "undefines"),
     [
