@@ -10,6 +10,24 @@ def test_die():
         util.die(":(")
 
 
+def test_collect_option_values():
+    args = ["foo", "-foo", "baz", "-fooquux", "-Dfoo"]
+
+    assert util.collect_option_values(args, "-foo") == [(1, "baz"), (3, "quux")]
+    assert util.collect_option_values(args, "-foo", style=util.OptionValueStyle.Mash) == [
+        (3, "quux")
+    ]
+    assert util.collect_option_values(args, "-foo", style=util.OptionValueStyle.Space) == [
+        (1, "baz")
+    ]
+
+    args = ["foo", "-foo=bar", "-foo", "baz"]
+    assert util.collect_option_values(args, "-foo", style=util.OptionValueStyle.EqualOrSpace) == [
+        (1, "bar"),
+        (2, "baz"),
+    ]
+
+
 def test_rindex():
     assert util.rindex([1, 1, 2, 3, 4, 5], 1) == 1
     assert util.rindex([1, 1, 2, 3, 4, 5], 6) is None
